CREATE SEQUENCE hibernate_sequence START WITH 1 INCREMENT BY 1;

CREATE TABLE users
(
    id       INTEGER      NOT NULL,
    username VARCHAR(20)  NOT NULL,
    password VARCHAR(120) NOT NULL,
    CONSTRAINT pk_user PRIMARY KEY (id),
    CONSTRAINT uc_user_username UNIQUE (username)
);

CREATE TABLE refresh_token
(
    id          INTEGER      NOT NULL,
    expiry_date DATE         NOT NULL,
    token       VARCHAR(500) NOT NULL,
    user_id     INTEGER      NOT NULL,
    CONSTRAINT pk_refresh_token PRIMARY KEY (id)
);

CREATE TABLE axe
(
    id          INTEGER      NOT NULL,
    identifier  INTEGER      NOT NULL,
    short_title VARCHAR(100) NOT NULL,
    title       VARCHAR(200) NOT NULL,
    description VARCHAR(500) NULL,
    color       VARCHAR(7)   NOT NULL,
    CONSTRAINT pk_axe PRIMARY KEY (id),
    CONSTRAINT uc_axe_identifier UNIQUE (identifier, title, short_title)
);

CREATE TABLE question
(
    id          INTEGER      NOT NULL,
    axe_id      INTEGER      NOT NULL,
    user_id     INTEGER      NOT NULL,
    label       VARCHAR(200) NOT NULL,
    description VARCHAR(500) NULL,
    CONSTRAINT question_quiz PRIMARY KEY (id)
);

CREATE TABLE quiz
(
    id           INTEGER   NOT NULL,
    user_id      INTEGER   NOT NULL,
    created_date TIMESTAMP NOT NULL,
    CONSTRAINT pk_quiz PRIMARY KEY (id)
);

CREATE TABLE response
(
    id          INTEGER  NOT NULL,
    question_id INTEGER  NOT NULL,
    quiz_id     INTEGER  NOT NULL,
    score       SMALLINT NOT NULL,
    comment     VARCHAR(500),
    CONSTRAINT pk_response PRIMARY KEY (id)
);

CREATE VIEW quiz_score AS
SELECT
    DENSE_RANK() OVER(ORDER BY a.identifier, r.quiz_id) AS id
     ,a.identifier AS axe_identifier
     ,r.quiz_id as quiz_id
     ,AVG(r.score) as score_avg
FROM response r
         INNER JOIN QUESTION q ON q.id = r.question_id
         INNER JOIN AXE a ON a.id = q.axe_id
GROUP BY r.quiz_id, a.identifier;